@@ -23,7 +23,7 @@ except ModuleNotFoundError:
 
 from .utils import MirlKoi,Anosu,Lolicon,is_MirlKoi_tag
 
-Bot_NICKNAME = list(nonebot.get_driver().config.nickname)[0]
+Bot_NICKNAME = list(nonebot.get_driver().config.nickname)
 
 Bot_NICKNAME = Bot_NICKNAME[0] if Bot_NICKNAME else "色图bot"
 
